<?php

/**
 * @file
 * Page callbacks for administrator forms
 */

/**
 * @package OG Content Access
 * @subpackage Organic Groups
 * @author Liran Tal <liran.tal@gmail.com>
 */


/**
 * Form callback for admin settings
 */
function og_content_access_manage()
{
  // Get site roles.
  $roles = user_roles();
  $site_roles = array();
  foreach ($roles as $rid => $role_name) {
    $site_roles[check_plain($rid)] = check_plain($role_name);
  }

  // Get existing node content types.
  $site_content_types = node_get_types('names');

  // Get configured content access roles.
  $og_content_access_roles = variable_get('og_content_access_roles', array());

  $form['help'] = array(
    '#title' => t('Help'),
    '#description' => t('You may specify which roles will be granted access to each content type on the site'),
    '#type' => 'fieldset',
    '#collapsed' => FALSE,
    '#collapsible' => TRUE,
  );


  $form['content_types'] = array(
    '#title' => t('Content Type Access Control'),
    '#type' => 'fieldset',
    '#collapsed' => FALSE,
    '#collapsible' => TRUE,
  );

  foreach ($site_content_types as $type => $type_name)
  {
    $form['content_types'][$type] = array(
      '#title' => check_plain($type_name),
      '#type' => 'fieldset',
      '#collapsed' => TRUE,
      '#collapsible' => TRUE,
    );

    $form['content_types'][$type]['contenttype_' . $type] = array(
      '#title' => check_plain($type_name),
      '#type' => 'checkboxes',
      '#options' => $site_roles,
      '#default_value' => isset($og_content_access_roles[$type]) ? $og_content_access_roles[$type] : array(),
    );

  }

  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save'),
  );

  return $form;
}


/**
 * Form submit callback handler
 */
function og_content_access_manage_submit($form, &$form_state)
{
  $og_content_access_roles = array();

  foreach ($form_state['values'] as $item => $roles)
  {
    if (strpos($item, 'contenttype_') !== FALSE)
    {
      // Process it.
      $content_type = substr($item, strlen('contenttype_'));
      $og_content_access_roles[$content_type] = array_values(array_filter($roles));
    }
  }

  variable_set('og_content_access_roles', $og_content_access_roles);

  drupal_set_message(t('Successfully saved content access roles restrictions'));
}
